#include <zephyr/kernel.h>
#include <zephyr/drivers/gpio.h>
#include <zephyr/drivers/pwm.h>
#include "hw_init.h"

#define LED_RED_NODE   DT_NODELABEL(led_red)
#define LED_GREEN_NODE DT_NODELABEL(led_green)
#define BUTTON_NODE    DT_NODELABEL(zg_button)
#define PWM_BEEP_SPEC  DT_ALIAS(buzzer)  // alias musí být v .dts

static const struct gpio_dt_spec led_red   = GPIO_DT_SPEC_GET(LED_RED_NODE, gpios);
static const struct gpio_dt_spec led_green = GPIO_DT_SPEC_GET(LED_GREEN_NODE, gpios);
static const struct gpio_dt_spec button    = GPIO_DT_SPEC_GET(BUTTON_NODE, gpios);
static const struct pwm_dt_spec  pwm_beep  = PWM_DT_SPEC_GET(PWM_BEEP_SPEC);

bool hw_init(void)
{
    if (!device_is_ready(led_red.port)) {
        printk("LED_RED not ready!\n");
        return false;
    }

    if (!device_is_ready(led_green.port)) {
        printk("LED_GREEN not ready!\n");
        return false;
    }

    gpio_pin_configure_dt(&led_red, GPIO_OUTPUT_INACTIVE);
    gpio_pin_configure_dt(&led_green, GPIO_OUTPUT_INACTIVE);

    if (!device_is_ready(pwm_beep.dev)) {
        printk("PWM_BEEP not ready!\n");
        return false;
    }

    if (!device_is_ready(button.port)) {
        printk("BUTTON0 not ready!\n");
        return false;
    }

    gpio_pin_configure_dt(&button, GPIO_INPUT);  // Interrupt config až v TaskButton

    return true;
}

const struct gpio_dt_spec *get_led_red(void)
{
    return &led_red;
}

const struct gpio_dt_spec *get_led_green(void)
{
    return &led_green;
}

const struct gpio_dt_spec *get_button(void)
{
    return &button;
}

const struct pwm_dt_spec *get_pwm_beep(void)
{
    return &pwm_beep;
}
